@@ -97,7 +97,7 @@ use strict;
 use vars qw($VERSION);
 
 # The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 1.109 $, 10;
+$VERSION = substr q$Revision: 1.110 $, 10;
 
 
 #==============================
@@ -154,6 +154,19 @@ sub open {
 
 #------------------------------
 
+=item opened
+
+I<Instance method.>
+Is the scalar handle opened on something?
+
+=cut
+
+sub opened {
+    shift->{SR};
+}
+
+#------------------------------
+
 =item close
 
 I<Instance method.>
@@ -294,7 +307,7 @@ sub read {
 #------------------------------
 
 sub TIEHANDLE { shift->new(@_) }
-sub GETC      { die "IO::Scalar: GETC unimplemented" }
+sub GETC      { shift->getc(@_) }
 sub PRINT     { shift->print(@_) }
 sub PRINTF    { shift->print(sprintf(@_)) }
 sub READ      { shift->read(@_) }
@@ -417,7 +430,7 @@ __END__
 
 =head1 VERSION
 
-$Id: Scalar.pm,v 1.109 1998/03/23 05:55:47 eryq Exp $
+$Id: Scalar.pm,v 1.110 1998/03/27 07:30:34 eryq Exp $
 
 
 =head1 AUTHOR
@@ -425,8 +438,8 @@ $Id: Scalar.pm,v 1.109 1998/03/23 05:55:47 eryq Exp $
 Eryq (F<eryq@zeegee.com>).
 President, Zero G Inc (F<http://www.zeegee.com>).
 
-Thanks to Andy Glew for contributing C<getc>.
-
+Thanks to Andy Glew for contributing C<getc()>.
 
+Thanks to Brandon Browning for suggesting C<opened()>.
 
 =cut
